@@ -3,11 +3,13 @@ var group__builtin__tags =
     [ "EcsFirstUserComponentId", "group__builtin__tags.html#ga6d5d39da21cc9fc04531ea7312c10def", null ],
     [ "EcsFirstUserEntityId", "group__builtin__tags.html#ga784ae6bc895e7fcf2776a8ded2b52acc", null ],
     [ "EcsLastInternalComponentId", "group__builtin__tags.html#gac20e614cdf113b24df9a148e3eb4b0f4", null ],
+    [ "EcsSingleton", "group__builtin__tags.html#ga6c79b0c20cd3242dcb81fc33815a3f18", null ],
     [ "EcsAcyclic", "group__builtin__tags.html#ga1b398e9afd304643a01561b340b7f0f8", null ],
     [ "EcsAlias", "group__builtin__tags.html#ga25e3a764b002bdf9e8f73a030b509083", null ],
     [ "EcsAny", "group__builtin__tags.html#gad00a0e281529d7c28fd9fcbad130b625", null ],
     [ "EcsCanToggle", "group__builtin__tags.html#ga894237463e91f5c4e22df985fe589657", null ],
     [ "EcsChildOf", "group__builtin__tags.html#ga804836ca51fb3ed3e7346ad084265236", null ],
+    [ "EcsConstant", "group__builtin__tags.html#gaff85d5259f15f6e5aa3fa5a40d549b69", null ],
     [ "EcsDelete", "group__builtin__tags.html#ga7d543c3e1209deeaf02beed7cbf07fe0", null ],
     [ "EcsDependsOn", "group__builtin__tags.html#ga75284a6be9ced3dec1ad93a940cd3cfb", null ],
     [ "EcsDisabled", "group__builtin__tags.html#gae760009c850226d9a1ce6c0cb8502021", null ],
@@ -18,6 +20,7 @@ var group__builtin__tags =
     [ "EcsFlecs", "group__builtin__tags.html#gade83a7cd520064a380bdb304bdf661d9", null ],
     [ "EcsFlecsCore", "group__builtin__tags.html#ga86b04c1fae3d3534482a7a6b0c260a9a", null ],
     [ "EcsInherit", "group__builtin__tags.html#gaae5fb9a2bf875c1b9e9cdef614bb6e9a", null ],
+    [ "EcsInheritable", "group__builtin__tags.html#gacffc22aa555fcac0e915c9d39ab314d9", null ],
     [ "EcsIsA", "group__builtin__tags.html#ga61e41a3ca391d17da70b088989d9048b", null ],
     [ "EcsModule", "group__builtin__tags.html#gab2d35cd3ff9fd774f572cd938c0275e5", null ],
     [ "EcsMonitor", "group__builtin__tags.html#ga87f7aac501487750fa6e89d16287a1c9", null ],
@@ -36,8 +39,6 @@ var group__builtin__tags =
     [ "EcsOnStore", "group__builtin__tags.html#ga453264b09c6a84f245605e92bf22ce49", null ],
     [ "EcsOnTableCreate", "group__builtin__tags.html#ga3aa3f0e38642e1953d7d363c255c8d19", null ],
     [ "EcsOnTableDelete", "group__builtin__tags.html#ga390f60fd97c67425563761eddd7d2a22", null ],
-    [ "EcsOnTableEmpty", "group__builtin__tags.html#ga9715530b38ecf21ea6b0ca0728bef3a0", null ],
-    [ "EcsOnTableFill", "group__builtin__tags.html#ga7f3484b70943553e233342b03f25c69d", null ],
     [ "EcsOnUpdate", "group__builtin__tags.html#gae0c798414db2f9db20b9f34b005c823f", null ],
     [ "EcsOnValidate", "group__builtin__tags.html#gaa57bc034ba07157a9a8127de128aeb0c", null ],
     [ "EcsOverride", "group__builtin__tags.html#gaaa2dc88663a26fce3e6011504b4c47bc", null ],
