@@ -1,97 +1,119 @@
 var NAVTREEINDEX15 =
 {
+"structflecs_1_1observer__builder__i.html#ab88bcb57f143d7949961c5bc8d306ba4":[17,1,0,6,1,2],
+"structflecs_1_1observer__builder__i.html#ae5c6a5cdd3ab8ebb717ff09dd486016a":[17,1,0,6,1,3],
+"structflecs_1_1opaque.html":[17,1,1,6,2],
+"structflecs_1_1opaque.html#a040618f3874d9431bea50e67b5553d43":[17,1,1,6,2,2],
+"structflecs_1_1opaque.html#a1d0315d802d3559c19233b672d03ba68":[17,1,1,6,2,9],
+"structflecs_1_1opaque.html#a2ad00197b46842dc8ff0b3e7d782fb04":[17,1,1,6,2,8],
+"structflecs_1_1opaque.html#a2bda9d424555300f33cbbe23c0c5cf22":[17,1,1,6,2,1],
+"structflecs_1_1opaque.html#a3c3c448d35a4e9487b53a37f0a08a0f2":[17,1,1,6,2,0],
+"structflecs_1_1opaque.html#a3d1fd3c2fe3cb11c2d3dc9579e08abbb":[17,1,1,6,2,4],
+"structflecs_1_1opaque.html#a3f09e5692b4c139874c1283c2b326674":[17,1,1,6,2,3],
+"structflecs_1_1opaque.html#a4c17cd1ef8996fa2133448d64985b65c":[17,1,1,6,2,18],
+"structflecs_1_1opaque.html#a57679d5e51c9ca920746cedb1c340513":[17,1,1,6,2,14],
+"structflecs_1_1opaque.html#a58b0ffa4e5bb2db1aaa7a7e87ba82bf4":[17,1,1,6,2,7],
+"structflecs_1_1opaque.html#a591ca77f7af02681ba82eeea99bd9851":[17,1,1,6,2,5],
+"structflecs_1_1opaque.html#a5c9dd9cbbb76d22ad10940a1eaa1661d":[17,1,1,6,2,16],
+"structflecs_1_1opaque.html#a5e8aae97d850673773dd22446fed71d9":[17,1,1,6,2,13],
 "structflecs_1_1opaque.html#a5f30eb4fa4a9c480d28694ccea0fd62c":[17,1,1,6,2,10],
+"structflecs_1_1opaque.html#a73c8866d65417104dea3005ea5d43e25":[17,1,1,6,2,17],
 "structflecs_1_1opaque.html#a9c1ba073c26bbc4e273c42a2e7636f70":[17,1,1,6,2,12],
 "structflecs_1_1opaque.html#abc72eb5a8ec7785b62c8ff26058bf5c4":[17,1,1,6,2,15],
 "structflecs_1_1opaque.html#add6d4f9c3e23fe3a410d620846585ea3":[17,1,1,6,2,11],
 "structflecs_1_1opaque.html#afbfc69ca8b72a6190e4bbb795458ff67":[17,1,1,6,2,6],
-"structflecs_1_1page__iterable.html":[18,0,0,45],
-"structflecs_1_1page__iterable.html":[19,0,0,45],
+"structflecs_1_1page__iterable.html":[18,0,0,46],
+"structflecs_1_1page__iterable.html":[19,0,0,46],
 "structflecs_1_1pair.html":[17,1,0,8,1],
 "structflecs_1_1pipeline.html":[17,1,1,9,2],
 "structflecs_1_1pipeline__builder.html":[17,1,1,9,0],
 "structflecs_1_1pipeline__builder__i.html":[17,1,1,9,1],
 "structflecs_1_1query.html":[17,1,0,7,2],
-"structflecs_1_1query__base.html":[18,0,0,51],
-"structflecs_1_1query__base.html":[19,0,0,51],
-"structflecs_1_1query__base.html#a0ad5a8a2e4b98d4b59ae4dd9be36486a":[18,0,0,51,0],
-"structflecs_1_1query__base.html#a0ad5a8a2e4b98d4b59ae4dd9be36486a":[19,0,0,51,0],
-"structflecs_1_1query__base.html#a293dec597aec3111f1f2052067a7cbba":[18,0,0,51,2],
-"structflecs_1_1query__base.html#a293dec597aec3111f1f2052067a7cbba":[19,0,0,51,2],
-"structflecs_1_1query__base.html#a45603b647327f89c3d2418166af9c93e":[18,0,0,51,4],
-"structflecs_1_1query__base.html#a45603b647327f89c3d2418166af9c93e":[19,0,0,51,4],
-"structflecs_1_1query__base.html#adb464df4e6b2255bec2d408aa9a6a9e7":[18,0,0,51,3],
-"structflecs_1_1query__base.html#adb464df4e6b2255bec2d408aa9a6a9e7":[19,0,0,51,3],
-"structflecs_1_1query__base.html#ae788911f0a5cb6afb580192774d7a3b0":[18,0,0,51,1],
-"structflecs_1_1query__base.html#ae788911f0a5cb6afb580192774d7a3b0":[19,0,0,51,1],
-"structflecs_1_1query__base.html#ga6409d9ef8b8dd7b365ae41b3a96b416c":[18,0,0,215],
-"structflecs_1_1query__base.html#ga6409d9ef8b8dd7b365ae41b3a96b416c":[18,0,0,51,5],
-"structflecs_1_1query__base.html#ga6409d9ef8b8dd7b365ae41b3a96b416c":[19,0,0,51,5],
+"structflecs_1_1query__base.html":[18,0,0,52],
+"structflecs_1_1query__base.html":[19,0,0,52],
+"structflecs_1_1query__base.html#a0ad5a8a2e4b98d4b59ae4dd9be36486a":[18,0,0,52,0],
+"structflecs_1_1query__base.html#a0ad5a8a2e4b98d4b59ae4dd9be36486a":[19,0,0,52,0],
+"structflecs_1_1query__base.html#a293dec597aec3111f1f2052067a7cbba":[18,0,0,52,2],
+"structflecs_1_1query__base.html#a293dec597aec3111f1f2052067a7cbba":[19,0,0,52,2],
+"structflecs_1_1query__base.html#a45603b647327f89c3d2418166af9c93e":[18,0,0,52,4],
+"structflecs_1_1query__base.html#a45603b647327f89c3d2418166af9c93e":[19,0,0,52,4],
+"structflecs_1_1query__base.html#adb464df4e6b2255bec2d408aa9a6a9e7":[18,0,0,52,3],
+"structflecs_1_1query__base.html#adb464df4e6b2255bec2d408aa9a6a9e7":[19,0,0,52,3],
+"structflecs_1_1query__base.html#ae788911f0a5cb6afb580192774d7a3b0":[18,0,0,52,1],
+"structflecs_1_1query__base.html#ae788911f0a5cb6afb580192774d7a3b0":[19,0,0,52,1],
+"structflecs_1_1query__base.html#ga6409d9ef8b8dd7b365ae41b3a96b416c":[18,0,0,219],
+"structflecs_1_1query__base.html#ga6409d9ef8b8dd7b365ae41b3a96b416c":[18,0,0,52,5],
+"structflecs_1_1query__base.html#ga6409d9ef8b8dd7b365ae41b3a96b416c":[19,0,0,52,5],
 "structflecs_1_1query__builder.html":[17,1,0,7,0],
 "structflecs_1_1query__builder__i.html":[17,1,0,7,1],
+"structflecs_1_1query__builder__i.html#a066e9c18f583d08f5333da641755d6ad":[17,1,0,7,1,12],
 "structflecs_1_1query__builder__i.html#a0b7332fe60cb4a514a9dd58b2e94e1c1":[17,1,0,7,1,0],
 "structflecs_1_1query__builder__i.html#a2a35c8e732bd7b397c055c70d2d520f7":[17,1,0,7,1,6],
 "structflecs_1_1query__builder__i.html#a48e767617cbb06e16b0fc2d15a678feb":[17,1,0,7,1,2],
 "structflecs_1_1query__builder__i.html#a5982fa9876c3d573724a61f7b2ba4e82":[17,1,0,7,1,5],
 "structflecs_1_1query__builder__i.html#a81c2736ca185e3daafb287c8b6bf63e4":[17,1,0,7,1,1],
 "structflecs_1_1query__builder__i.html#a96253778fc99223329c61dab09041aff":[17,1,0,7,1,3],
+"structflecs_1_1query__builder__i.html#a98e049b9a43d436198d5fd39bf7d17b7":[17,1,0,7,1,11],
+"structflecs_1_1query__builder__i.html#a99ed26ed8841a7ecbb72a9f68fbe4385":[17,1,0,7,1,9],
 "structflecs_1_1query__builder__i.html#ac66c195ea77f223eb23b33e835526e23":[17,1,0,7,1,8],
 "structflecs_1_1query__builder__i.html#ac7224dd31757845b46aeff2e6f8e8fba":[17,1,0,7,1,4],
+"structflecs_1_1query__builder__i.html#ae34317292fe22188428e8c95284b24d5":[17,1,0,7,1,10],
 "structflecs_1_1query__builder__i.html#ae694d98997987fb6450d78774dee7d26":[17,1,0,7,1,7],
-"structflecs_1_1ref.html":[17,1,0,9,0],
-"structflecs_1_1ref.html#af52554da7a9060c919b089f5a57e0cb4":[17,1,0,9,0,0],
+"structflecs_1_1ref.html":[17,1,0,9,1],
 "structflecs_1_1scoped__world.html":[17,1,0,12,1],
 "structflecs_1_1script__builder.html":[17,1,1,11,0],
-"structflecs_1_1second__arg.html":[18,0,0,57],
-"structflecs_1_1second__arg.html":[19,0,0,57],
-"structflecs_1_1second__arg__impl.html":[18,0,0,58],
+"structflecs_1_1second__arg.html":[18,0,0,58],
+"structflecs_1_1second__arg.html":[19,0,0,58],
 "structflecs_1_1second__arg__impl.html":[18,0,0,59],
-"structflecs_1_1second__arg__impl.html":[19,0,0,58],
 "structflecs_1_1second__arg__impl.html":[19,0,0,59],
+"structflecs_1_1second__arg__impl_3_01Func_00_01___1_1arg__list_3_01First_00_01T_00_01Args_01_8_8_8_01_4_01_4.html":[18,0,0,60],
+"structflecs_1_1second__arg__impl_3_01Func_00_01___1_1arg__list_3_01First_00_01T_00_01Args_01_8_8_8_01_4_01_4.html":[19,0,0,60],
 "structflecs_1_1stats.html":[17,1,1,12,0],
-"structflecs_1_1string.html":[18,0,0,61],
-"structflecs_1_1string.html":[19,0,0,61],
-"structflecs_1_1string__view.html":[18,0,0,62],
-"structflecs_1_1string__view.html":[19,0,0,62],
-"structflecs_1_1stringstream.html":[18,0,0,63],
-"structflecs_1_1stringstream.html":[19,0,0,63],
-"structflecs_1_1system.html":[18,0,0,64],
-"structflecs_1_1system.html":[19,0,0,64],
-"structflecs_1_1system.html#a30bd0179e128c6d037bc901a6c27b31b":[18,0,0,208],
-"structflecs_1_1system.html#a30bd0179e128c6d037bc901a6c27b31b":[18,0,0,64,18],
-"structflecs_1_1system.html#a30bd0179e128c6d037bc901a6c27b31b":[19,0,0,64,18],
-"structflecs_1_1system.html#a348b5352a9b2dc459d65bccd322ad1f0":[18,0,0,137],
-"structflecs_1_1system.html#a348b5352a9b2dc459d65bccd322ad1f0":[18,0,0,64,6],
-"structflecs_1_1system.html#a348b5352a9b2dc459d65bccd322ad1f0":[19,0,0,64,6],
-"structflecs_1_1system.html#a5507fae8c3f326e957f468372b63b322":[18,0,0,64,3],
-"structflecs_1_1system.html#a5507fae8c3f326e957f468372b63b322":[19,0,0,64,3],
-"structflecs_1_1system.html#a60de64d75454385b23995437f1d72669":[18,0,0,200],
-"structflecs_1_1system.html#a60de64d75454385b23995437f1d72669":[18,0,0,64,14],
-"structflecs_1_1system.html#a60de64d75454385b23995437f1d72669":[19,0,0,64,14],
-"structflecs_1_1system.html#a8baaadf7cffb365c70109d5b00e54fea":[18,0,0,64,0],
-"structflecs_1_1system.html#a8baaadf7cffb365c70109d5b00e54fea":[19,0,0,64,0],
-"structflecs_1_1system.html#a8c528baf37154d347366083f0f816846":[18,0,0,201],
-"structflecs_1_1system.html#a8c528baf37154d347366083f0f816846":[18,0,0,64,16],
-"structflecs_1_1system.html#a8c528baf37154d347366083f0f816846":[19,0,0,64,16],
-"structflecs_1_1system.html#a8f1ef9547c83c1733bde900a3b8b5b00":[18,0,0,197],
-"structflecs_1_1system.html#a8f1ef9547c83c1733bde900a3b8b5b00":[18,0,0,64,10],
-"structflecs_1_1system.html#a8f1ef9547c83c1733bde900a3b8b5b00":[19,0,0,64,10],
-"structflecs_1_1system.html#a92b0d661481579937243d5f7a0cf8e76":[18,0,0,176],
-"structflecs_1_1system.html#a92b0d661481579937243d5f7a0cf8e76":[18,0,0,64,8],
-"structflecs_1_1system.html#a92b0d661481579937243d5f7a0cf8e76":[19,0,0,64,8],
-"structflecs_1_1system.html#a9d2361efe2ea358b3bd0728408ced507":[18,0,0,64,1],
-"structflecs_1_1system.html#a9d2361efe2ea358b3bd0728408ced507":[19,0,0,64,1],
-"structflecs_1_1system.html#ac475621a5fb9513885c12474ba7ffd67":[18,0,0,64,2],
-"structflecs_1_1system.html#ac475621a5fb9513885c12474ba7ffd67":[19,0,0,64,2],
-"structflecs_1_1system.html#ad9fcdd6a0ff2f52e63f5ca0c9b144543":[18,0,0,209],
-"structflecs_1_1system.html#ad9fcdd6a0ff2f52e63f5ca0c9b144543":[18,0,0,64,20],
-"structflecs_1_1system.html#ad9fcdd6a0ff2f52e63f5ca0c9b144543":[19,0,0,64,20],
-"structflecs_1_1system.html#afacd9721ff3f5ae88a3fcf103a7713cd":[18,0,0,198],
-"structflecs_1_1system.html#afacd9721ff3f5ae88a3fcf103a7713cd":[18,0,0,64,12],
-"structflecs_1_1system.html#afacd9721ff3f5ae88a3fcf103a7713cd":[19,0,0,64,12],
-"structflecs_1_1system.html#ga34a1a0b44ceace9c28e66ab008d9a97f":[18,0,0,138],
-"structflecs_1_1system.html#ga34a1a0b44ceace9c28e66ab008d9a97f":[18,0,0,64,4],
-"structflecs_1_1system.html#ga34a1a0b44ceace9c28e66ab008d9a97f":[19,0,0,64,4],
+"structflecs_1_1string.html":[18,0,0,62],
+"structflecs_1_1string.html":[19,0,0,62],
+"structflecs_1_1string__view.html":[18,0,0,63],
+"structflecs_1_1string__view.html":[19,0,0,63],
+"structflecs_1_1stringstream.html":[18,0,0,64],
+"structflecs_1_1stringstream.html":[19,0,0,64],
+"structflecs_1_1system.html":[18,0,0,65],
+"structflecs_1_1system.html":[19,0,0,65],
+"structflecs_1_1system.html#a30bd0179e128c6d037bc901a6c27b31b":[18,0,0,212],
+"structflecs_1_1system.html#a30bd0179e128c6d037bc901a6c27b31b":[18,0,0,65,19],
+"structflecs_1_1system.html#a30bd0179e128c6d037bc901a6c27b31b":[19,0,0,65,19],
+"structflecs_1_1system.html#a348b5352a9b2dc459d65bccd322ad1f0":[18,0,0,141],
+"structflecs_1_1system.html#a348b5352a9b2dc459d65bccd322ad1f0":[18,0,0,65,7],
+"structflecs_1_1system.html#a348b5352a9b2dc459d65bccd322ad1f0":[19,0,0,65,7],
+"structflecs_1_1system.html#a5507fae8c3f326e957f468372b63b322":[18,0,0,65,3],
+"structflecs_1_1system.html#a5507fae8c3f326e957f468372b63b322":[19,0,0,65,3],
+"structflecs_1_1system.html#a60de64d75454385b23995437f1d72669":[18,0,0,204],
+"structflecs_1_1system.html#a60de64d75454385b23995437f1d72669":[18,0,0,65,15],
+"structflecs_1_1system.html#a60de64d75454385b23995437f1d72669":[19,0,0,65,15],
+"structflecs_1_1system.html#a8baaadf7cffb365c70109d5b00e54fea":[18,0,0,65,0],
+"structflecs_1_1system.html#a8baaadf7cffb365c70109d5b00e54fea":[19,0,0,65,0],
+"structflecs_1_1system.html#a8c528baf37154d347366083f0f816846":[18,0,0,205],
+"structflecs_1_1system.html#a8c528baf37154d347366083f0f816846":[18,0,0,65,17],
+"structflecs_1_1system.html#a8c528baf37154d347366083f0f816846":[19,0,0,65,17],
+"structflecs_1_1system.html#a8f1ef9547c83c1733bde900a3b8b5b00":[18,0,0,201],
+"structflecs_1_1system.html#a8f1ef9547c83c1733bde900a3b8b5b00":[18,0,0,65,11],
+"structflecs_1_1system.html#a8f1ef9547c83c1733bde900a3b8b5b00":[19,0,0,65,11],
+"structflecs_1_1system.html#a92b0d661481579937243d5f7a0cf8e76":[18,0,0,180],
+"structflecs_1_1system.html#a92b0d661481579937243d5f7a0cf8e76":[18,0,0,65,9],
+"structflecs_1_1system.html#a92b0d661481579937243d5f7a0cf8e76":[19,0,0,65,9],
+"structflecs_1_1system.html#a9d2361efe2ea358b3bd0728408ced507":[18,0,0,65,1],
+"structflecs_1_1system.html#a9d2361efe2ea358b3bd0728408ced507":[19,0,0,65,1],
+"structflecs_1_1system.html#ac343dbb0c6a3cd44bd97863127a1c2a0":[18,0,0,65,4],
+"structflecs_1_1system.html#ac343dbb0c6a3cd44bd97863127a1c2a0":[19,0,0,65,4],
+"structflecs_1_1system.html#ac475621a5fb9513885c12474ba7ffd67":[18,0,0,65,2],
+"structflecs_1_1system.html#ac475621a5fb9513885c12474ba7ffd67":[19,0,0,65,2],
+"structflecs_1_1system.html#ad9fcdd6a0ff2f52e63f5ca0c9b144543":[18,0,0,213],
+"structflecs_1_1system.html#ad9fcdd6a0ff2f52e63f5ca0c9b144543":[18,0,0,65,21],
+"structflecs_1_1system.html#ad9fcdd6a0ff2f52e63f5ca0c9b144543":[19,0,0,65,21],
+"structflecs_1_1system.html#afacd9721ff3f5ae88a3fcf103a7713cd":[18,0,0,202],
+"structflecs_1_1system.html#afacd9721ff3f5ae88a3fcf103a7713cd":[18,0,0,65,13],
+"structflecs_1_1system.html#afacd9721ff3f5ae88a3fcf103a7713cd":[19,0,0,65,13],
+"structflecs_1_1system.html#ga34a1a0b44ceace9c28e66ab008d9a97f":[18,0,0,142],
+"structflecs_1_1system.html#ga34a1a0b44ceace9c28e66ab008d9a97f":[18,0,0,65,5],
+"structflecs_1_1system.html#ga34a1a0b44ceace9c28e66ab008d9a97f":[19,0,0,65,5],
 "structflecs_1_1system__builder.html":[17,1,1,13,1],
 "structflecs_1_1system__builder__i.html":[17,1,1,13,2],
 "structflecs_1_1system__builder__i.html#a108cb748eb7350ed94deeefa129ea321":[17,1,1,13,2,4],
@@ -105,8 +127,8 @@ var NAVTREEINDEX15 =
 "structflecs_1_1system__builder__i.html#ab97725a95f79df7f5ec77a8f3bb45ff5":[17,1,1,13,2,2],
 "structflecs_1_1system__builder__i.html#ad47c0a6fae17be2c0ecd6413209e33ad":[17,1,1,13,2,9],
 "structflecs_1_1system__builder__i.html#afc1a155d412834f143c3ec7301927f2e":[17,1,1,13,2,5],
-"structflecs_1_1system__runner__fluent.html":[18,0,0,67],
-"structflecs_1_1system__runner__fluent.html":[19,0,0,67],
+"structflecs_1_1system__runner__fluent.html":[18,0,0,68],
+"structflecs_1_1system__runner__fluent.html":[19,0,0,68],
 "structflecs_1_1table.html":[17,1,0,10,0],
 "structflecs_1_1table.html#a058d61966f00499d053dff8039ca2a14":[17,1,0,10,0,9],
 "structflecs_1_1table.html#a058d61966f00499d053dff8039ca2a14":[17,1,0,10,0,10],
@@ -155,19 +177,21 @@ var NAVTREEINDEX15 =
 "structflecs_1_1term__builder__i.html#adf9100a193a1f4a8d647cf13025a168a":[17,1,0,7,4,0],
 "structflecs_1_1term__builder__i.html#af189122a0ccf461176f94c160fb8a95d":[17,1,0,7,4,11],
 "structflecs_1_1term__ref__builder__i.html":[17,1,0,7,3],
-"structflecs_1_1timer.html":[18,0,0,73],
-"structflecs_1_1timer.html":[19,0,0,73],
-"structflecs_1_1timer.html#a5507fae8c3f326e957f468372b63b322":[18,0,0,73,3],
-"structflecs_1_1timer.html#a5507fae8c3f326e957f468372b63b322":[19,0,0,73,3],
-"structflecs_1_1timer.html#a8baaadf7cffb365c70109d5b00e54fea":[18,0,0,73,0],
-"structflecs_1_1timer.html#a8baaadf7cffb365c70109d5b00e54fea":[19,0,0,73,0],
-"structflecs_1_1timer.html#a9d2361efe2ea358b3bd0728408ced507":[18,0,0,73,1],
-"structflecs_1_1timer.html#a9d2361efe2ea358b3bd0728408ced507":[19,0,0,73,1],
-"structflecs_1_1timer.html#ac475621a5fb9513885c12474ba7ffd67":[18,0,0,73,2],
-"structflecs_1_1timer.html#ac475621a5fb9513885c12474ba7ffd67":[19,0,0,73,2],
+"structflecs_1_1timer.html":[18,0,0,74],
+"structflecs_1_1timer.html":[19,0,0,74],
+"structflecs_1_1timer.html#a5507fae8c3f326e957f468372b63b322":[18,0,0,74,3],
+"structflecs_1_1timer.html#a5507fae8c3f326e957f468372b63b322":[19,0,0,74,3],
+"structflecs_1_1timer.html#a8baaadf7cffb365c70109d5b00e54fea":[18,0,0,74,0],
+"structflecs_1_1timer.html#a8baaadf7cffb365c70109d5b00e54fea":[19,0,0,74,0],
+"structflecs_1_1timer.html#a9d2361efe2ea358b3bd0728408ced507":[18,0,0,74,1],
+"structflecs_1_1timer.html#a9d2361efe2ea358b3bd0728408ced507":[19,0,0,74,1],
+"structflecs_1_1timer.html#ac343dbb0c6a3cd44bd97863127a1c2a0":[18,0,0,74,4],
+"structflecs_1_1timer.html#ac343dbb0c6a3cd44bd97863127a1c2a0":[19,0,0,74,4],
+"structflecs_1_1timer.html#ac475621a5fb9513885c12474ba7ffd67":[18,0,0,74,2],
+"structflecs_1_1timer.html#ac475621a5fb9513885c12474ba7ffd67":[19,0,0,74,2],
 "structflecs_1_1type.html":[17,1,0,11,0],
-"structflecs_1_1units.html":[18,0,0,75],
-"structflecs_1_1units.html":[19,0,0,75],
+"structflecs_1_1units.html":[18,0,0,76],
+"structflecs_1_1units.html":[19,0,0,76],
 "structflecs_1_1units_1_1Amount.html":[17,1,1,15,1,6],
 "structflecs_1_1units_1_1Angle.html":[17,1,1,15,1,13],
 "structflecs_1_1units_1_1Atto.html":[17,1,1,15,0,2],
@@ -225,29 +249,5 @@ var NAVTREEINDEX15 =
 "structflecs_1_1units_1_1color.html":[17,1,1,15,36],
 "structflecs_1_1units_1_1color_1_1Css.html":[17,1,1,15,18,2],
 "structflecs_1_1units_1_1color_1_1Hsl.html":[17,1,1,15,18,1],
-"structflecs_1_1units_1_1color_1_1Rgb.html":[17,1,1,15,18,0],
-"structflecs_1_1units_1_1data.html":[17,1,1,15,32],
-"structflecs_1_1units_1_1data_1_1Bits.html":[17,1,1,15,14,0],
-"structflecs_1_1units_1_1data_1_1Bytes.html":[17,1,1,15,14,4],
-"structflecs_1_1units_1_1data_1_1GibiBytes.html":[17,1,1,15,14,10],
-"structflecs_1_1units_1_1data_1_1GigaBits.html":[17,1,1,15,14,3],
-"structflecs_1_1units_1_1data_1_1GigaBytes.html":[17,1,1,15,14,7],
-"structflecs_1_1units_1_1data_1_1KibiBytes.html":[17,1,1,15,14,8],
-"structflecs_1_1units_1_1data_1_1KiloBits.html":[17,1,1,15,14,1],
-"structflecs_1_1units_1_1data_1_1KiloBytes.html":[17,1,1,15,14,5],
-"structflecs_1_1units_1_1data_1_1MebiBytes.html":[17,1,1,15,14,9],
-"structflecs_1_1units_1_1data_1_1MegaBits.html":[17,1,1,15,14,2],
-"structflecs_1_1units_1_1data_1_1MegaBytes.html":[17,1,1,15,14,6],
-"structflecs_1_1units_1_1datarate.html":[17,1,1,15,33],
-"structflecs_1_1units_1_1datarate_1_1BitsPerSecond.html":[17,1,1,15,15,0],
-"structflecs_1_1units_1_1datarate_1_1BytesPerSecond.html":[17,1,1,15,15,4],
-"structflecs_1_1units_1_1datarate_1_1GigaBitsPerSecond.html":[17,1,1,15,15,3],
-"structflecs_1_1units_1_1datarate_1_1GigaBytesPerSecond.html":[17,1,1,15,15,7],
-"structflecs_1_1units_1_1datarate_1_1KiloBitsPerSecond.html":[17,1,1,15,15,1],
-"structflecs_1_1units_1_1datarate_1_1KiloBytesPerSecond.html":[17,1,1,15,15,5],
-"structflecs_1_1units_1_1datarate_1_1MegaBitsPerSecond.html":[17,1,1,15,15,2],
-"structflecs_1_1units_1_1datarate_1_1MegaBytesPerSecond.html":[17,1,1,15,15,6],
-"structflecs_1_1units_1_1duration.html":[17,1,1,15,20],
-"structflecs_1_1units_1_1duration_1_1Days.html":[17,1,1,15,2,7],
-"structflecs_1_1units_1_1duration_1_1Hours.html":[17,1,1,15,2,6]
+"structflecs_1_1units_1_1color_1_1Rgb.html":[17,1,1,15,18,0]
 };
